@@ -183,3 +183,38 @@ def attachSettings(settingsDict, enablePaypal=False):
             settingsDict['OSCAR_DASHBOARD_NAVIGATION'] = ADDING_OSCAR_DASHBOARD_NAVIGATION
     #=========================================================================
 
+def attachShopURLs(settings, urlpatterns):
+    """
+    Attach shop related urlpatterns.
+    It must be called in urls.py by passing urlpatterns.
+ 
+    @param settings Django project's settings module.
+    @param urlpatterns urlpatterns in urls.py.
+    """
+
+    from django.conf.urls import url, include, patterns
+    from oscar.app import application as shop
+
+    urlpatterns += patterns('',
+        (r'^i18n/', include('django.conf.urls.i18n')),
+        (r'', include(shop.urls)),
+
+    )
+
+def attachPaypalURLs(settings, urlpatterns):
+    """
+    Attach paypal related urlpatterns.
+    It must be called in urls.py by passing urlpatterns.
+ 
+    @param settings Django project's settings module.
+    @param urlpatterns urlpatterns in urls.py.
+    """
+
+    from django.conf.urls import url, include, patterns
+    from paypal.express.dashboard.app import application
+
+    urlpatterns += patterns('',
+        (r'^checkout/payment-details/', include('paypal.express.urls')),
+        (r'^shop/dashboard/paypal/express/', include(application.urls)),
+
+    )
\ No newline at end of file
